@@ -1,7 +1,7 @@
 /*
  * util.c: Helper functions for miscellaneous tasks
  *
- * Copyright (C) 2004-2006 xchat-gnome team
+ * Copyright (C) 2004-2007 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,17 +25,17 @@
 #include <string.h>
 #include "util.h"
 #include "gui.h"
+#include "../common/xchatc.h"
 
 void
 error_dialog (const gchar *header, const gchar *message)
 {
-	GtkWidget *dialog;
-
-	dialog = gtk_message_dialog_new (GTK_WINDOW (gui.main_window),
-					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_OK,
-					 "%s", header);
+	GtkWidget *dialog =
+		gtk_message_dialog_new (GTK_WINDOW (gui.main_window),
+		                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+		                        GTK_MESSAGE_ERROR,
+		                        GTK_BUTTONS_OK,
+		                        "%s", header);
 
 	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog), "%s", message);
 
@@ -43,42 +43,6 @@ error_dialog (const gchar *header, const gchar *message)
 	gtk_widget_destroy (dialog);
 }
 
-gint gtk_tree_iter_sort_func_nocase (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data)
-{
-	gchar *as, *bs;
-	gint result;
-
-	gtk_tree_model_get (model, a, 1, &as, -1);
-	gtk_tree_model_get (model, b, 1, &bs, -1);
-
-	if (as == NULL) {
-		return 1;
-	}
-
-	if (bs == NULL) {
-		g_free (as);
-		return -1;
-	}
-
-	result = strcasecmp (as, bs);
-
-	g_free (as);
-	g_free (bs);
-
-	/* GtkTreeSortable has undefined results if this function isn't
-	 * reflexive, antisymmetric and transitive.  If the two strings are
-	 * equal, compare session pointers */
-	if (result == 0) {
-		gpointer ap, bp;
-		gtk_tree_model_get (model, a, 2, &ap, -1);
-		gtk_tree_model_get (model, b, 2, &bp, -1);
-
-		return (GPOINTER_TO_UINT(ap) - GPOINTER_TO_UINT(bp));
-	}
-
-	return result;
-}
-
 gboolean
 dialog_escape_key_handler_destroy (GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
@@ -182,3 +146,15 @@ locate_data_file (const gchar *file_name)
 
 	return path;
 }
+
+server *
+find_connected_server (ircnet *network)
+{
+	for (GSList *i = sess_list; i; i = g_slist_next (i)) {
+		session *sess = (session *)(i->data);
+		if (sess->server->network == network) {
+			return sess->server;
+		}
+	}
+	return NULL;
+}
